#########################
Canvas CPP Grader Project
#########################

This project aims at creating a toolkit for grading C/C++ submissions from Canvas LMS. The toolkit consumes a directory containing submissions and outputs a filtered, regorgainzed artifact and build reports.

**Warning** This project is under development

****
TODO
****

- Add support for multiple submissions per student
- Add more flexible anti-plagiarism techniques.
- Add support for multiple programming languages
- Add support for build systems other than Makefile/CMake
- Add support for cmdline arguments such as ``CXX_STANDARD``